@@ -1,6 +1,6 @@
 /*
     dtaus.c - Belegloser Datentrgeraustausch mit einer Bank
-    Copyright (c) 1996,8,2001,2  Martin Schulze <joey@infodrom.org>
+    Copyright (c) 1996,8,2001-4  Martin Schulze <joey@infodrom.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111, USA.
 
-    $Id: dtaus.c,v 1.27 2002/01/01 18:52:06 joey Exp $
+    $Id: dtaus.c,v 1.38 2004/08/06 20:50:09 joey Exp $
  */
 
 #include "dtaus.h"
@@ -27,10 +27,13 @@
 #include <ctype.h>
 #include <time.h>
 #include <malloc.h>
+#include "latex.h"
 
 #define DEFAULT_EURO
 #ifndef DEFAULT_EURO
 int use_euro = 0;
+#else
+int use_euro = 1;
 #endif
 
 /*
@@ -61,7 +64,9 @@ dtaus_record recA[] = {
   {"Referenz", 70, 10, OPT},
   {"Datum", 50, 6, IGN},
   {"Ausfuehrung", 95, 8, OPT},
+  {"Currency", 127, 1, OPT},
   {"Euro", 127, 1, OPT},
+  {"DM", 127, 1, OPT},
   {NULL, 0, 0}
 };
 
@@ -72,8 +77,11 @@ dtaus_record recA[] = {
 #define A_REF	4
 #define A_DATE	5
 #define A_TODO	6
-#define A_EURO	7
-#define A_LEN	8
+#define A_CURR	7
+#define A_EURO	8
+#define A_DM	9
+#define A_LEN	10
+#define A_LOOP	7
 
 dtaus_record recC[] = {
   {"Name", 93, 27, REQ},
@@ -89,11 +97,13 @@ dtaus_record recC[] = {
   {"myName", 128, 27, OPT},
   {"myKonto", 69, 10, OPT},
   {"myBLZ", 61, 8, OPT},
-  {"Euro", 182, 1, IGN},
   {"Text", 187, 29, OPT},
   {"Extension", 216, 29, OPT},
+  {"Currency", 182, 1, IGN},
 #ifndef DEFAULT_EURO
   {"Betrag-Euro", 79, 11, IGN},
+#else
+  {"Betrag-DM", 50, 11, IGN},
 #endif
   {NULL, 0, 0}
 };
@@ -107,15 +117,16 @@ dtaus_record recC[] = {
 #define C_MYNAM	6
 #define C_MYKTO	7
 #define C_MYBLZ	8
-#define C_EURO  9
-#define C_TEXT 10
-#define C_EXT  11
+#define C_TEXT  9
+#define C_EXT  10
+#define C_EURO 11
 #ifndef DEFAULT_EURO
 #define C_EUR  12
-#define C_LEN  13
 #else
-#define C_LEN  12
+#define C_DM   12
 #endif
+#define C_LEN  13
+#define C_LOOP 11
 
 #define MAX_TEXT 14
 
@@ -130,6 +141,8 @@ dtaus_record recE[] = {
   {"BLZs", 47, 17, IGN},
 #ifndef DEFAULT_EURO
   {"Summe-Euro", 64, 13, IGN},
+#else
+  {"Summe-DM", 17, 13, IGN},
 #endif
   {NULL, 0, 0}
 };
@@ -140,7 +153,10 @@ dtaus_record recE[] = {
 #define E_BLZ	3
 #ifndef DEFAULT_EURO
 #define E_EUR	4
+#else
+#define E_DM	4
 #endif
+#define E_LEN	5
 
 /*
  *  Second: Some low level routines
@@ -234,7 +250,7 @@ char *strip_nondigits (char *s)
 char dtaus_char (void *buf, unsigned int pos)
 {
   static char res;
-  char *bufp = buf;
+  char *bufp = (char *)buf;
 
   bufp+=pos;
   memcpy(&res, bufp, 1);
@@ -258,15 +274,57 @@ char *real2string(char *s)
 {
   static char res[20];
   char *cp;
+  char *xp;	/* only to avoid a GCC warning */
 
-  strcpy(res, s);
+  strncpy(res, s, sizeof(res)-1);
+  res[sizeof(res)-1] = 0;
   for (cp=res; *cp&&!(*cp == ',')&&!(*cp == '.');cp++);
-  *(cp++) = *(cp+1);
-  *(cp++) = *(cp+1);
+
+  if ((cp-res) >= (sizeof(res)-3)) { 
+    /* Bail out, since the number is too large, shouldn't be possible though. */
+    fprintf (stderr, "Value %s too large.\n", res);
+    exit (1);
+  }
+
+  if (*cp == '.' || *cp == ',') {
+    if (*(cp+1)) {
+      /* 1st decimal place */
+      xp = cp+1;
+      if (*xp && isdigit(*xp))
+	*(cp++) = *xp;
+      else
+	*(cp++) = '0';
+      /* 2nd decimal place */
+      xp = cp+1;
+      if (*xp && isdigit(*xp))
+	*(cp++) = *xp;
+      else
+	*(cp++) = '0';
+    } else {
+      *(cp++) = '0';
+      *(cp++) = '0';
+    }
+  } else {
+    *(cp++) = '0';
+    *(cp++) = '0';
+  }
   *cp = '\0';
   return res;
 }
 
+/*
+ * Return the last digit of the year as character
+ */
+char get_date_lastdigit()
+{
+  time_t timer;
+  struct tm *loctime;
+
+  timer = time ( NULL );
+  loctime = localtime(&timer);
+  return loctime->tm_year % 10 + '0';
+}
+
 char *string2trans (char *s)
 {
   static char res[30];
@@ -285,7 +343,7 @@ char *string2trans (char *s)
   else if (!strcmp(s, "53000"))
     sprintf (res, "Lohn");
   else if (!strncmp(s, "5400", 4))
-    sprintf (res, "Vermgen");
+    sprintf (res, "Vermgen %c",s[4]);
   /*  else if (!strcmp(s, "56000"))
     sprintf (res, ""); / * berweisung ffentlicher Kassen */
   return res;
@@ -294,6 +352,7 @@ char *string2trans (char *s)
 char *trans2string (char *s)
 {
   static char res[30];
+  char *cp;
 
   res[0] = '\0';
   if (!strcmp(s, "Abbuchung"))
@@ -308,8 +367,34 @@ char *trans2string (char *s)
     sprintf (res, "51000");
   else if (!strcmp(s, "Lohn"))
     sprintf (res, "53000");
-  else if (!strncmp(s, "Vermgen", 4))
-    sprintf (res, "5400");
+  else {
+    cp = NULL;
+    if (!strncmp(s, "Vermgen", 8))
+      cp = s+8;
+    if (!strncmp(s, "Vermoegen", 9))
+      cp = s+9;
+
+    if (!cp) {
+      fprintf (stderr, "Unbekannte Transaktion `%s'\n", res);
+      exit (1);
+    }
+
+    /*
+      Vermgen --> 5400<heutiges Jahr>
+      Vermgen 8 -> 5400<8>
+      Vermgen 2003 -> 5400<3>
+     */
+
+    if (*cp) while (!isspace(*cp)) cp++;
+    while (isspace(*cp)) cp++;
+
+    if (!*cp || !isdigit(*cp))
+      sprintf (res, "5400%c",get_date_lastdigit());
+    else {
+      while (isdigit(*cp)) cp++;
+      sprintf (res, "5400%c",*(cp-1));
+    }
+  }
   /*  else if (!strcmp(s, ""))
     sprintf (res, "56000"); / * berweisung ffentlicher Kassen */
   return res;
@@ -346,7 +431,7 @@ char *ext2string (char *s)
 unsigned long int dtaus_int(void *buf, unsigned int pos, unsigned int len)
 {
   char tmp[30];
-  char *bufp = buf;
+  char *bufp = (char *)buf;
   static unsigned long int res;
 
   bufp+=pos;
@@ -471,6 +556,9 @@ size_t control_nextline (void **buf, int len, FILE *f)
     return 0;
 }
 
+/*
+ * Return the current date nicely formatted
+ */
 char *get_date()
 {
   static char res[10];
@@ -509,14 +597,10 @@ void dtaus_prepareA (char *buf)
   for (i=56;i<56+4; i++) buf[i] = ' ';		/* A8 */
   for (i=70;i<70+10; i++) buf[i] = '0';		/* A10 */
   for (i=80;i<80+48; i++) buf[i] = ' ';		/* A11 */
-#ifdef DEFAULT_EURO
-  buf[recA[A_EURO].pos] = '1';				/* A12 (Currency) */
-#else
   if (use_euro)
-    buf[recA[A_EURO].pos] = '1';				/* A12 (Currency) */
+    buf[recA[A_CURR].pos] = '1';				/* A12 (Currency) */
   else
-    buf[recA[A_EURO].pos] = ' ';				/* A12 (Currency) */
-#endif
+    buf[recA[A_CURR].pos] = ' ';				/* A12 (Currency) */
 }
 
 /*
@@ -552,14 +636,10 @@ void dtaus_prepareC (char *buf, int normaltext, int maxtext)
   for (i=90;i<90+3; i++) buf[i] = ' ';		/* C13 */
   for (i=93;i<90+27; i++) buf[i] = ' ';		/* C14a (Kunde) */
   for (i=120;i<120+8; i++) buf[i] = ' ';	/* C14b */
-#ifdef DEFAULT_EURO
-  buf[recC[C_EURO].pos] = '1';				/* C17a (Currency) */
-#else
   if (use_euro)
     buf[recC[C_EURO].pos] = '1';				/* C17a (Currency) */
   else
     buf[recC[C_EURO].pos] = ' ';				/* C17a (Currency) */
-#endif
   for (i=183;i<183+2; i++) buf[i] = ' ';	/* C17b */
   for (i=187;i<187+(29*2); i++) buf[i] = ' ';	/* C19-C22 (misc text) */
   for (i=245;i<245+11; i++) buf[i] = ' ';	/* C23 */
@@ -651,7 +731,7 @@ int dtaus_writeC(FILE *f, char **valuesA, char **values, char **text)
     }
   sprintf (tmp, "%s", trans2string(values[C_TRANS]));
   if (!strlen(tmp)) {
-    fprintf (stderr, "Ungltiger Typ, nur Abbuchung, Einzug, E-Cash, E-Cash-A, Gutschrift und Lohn erlaubt.\n");
+    fprintf (stderr, "Ungltige Transaktion, nur Abbuchung, Einzug, E-Cash, E-Cash-A, Gutschrift und Lohn erlaubt.\n");
     return 0;
   }
 
@@ -683,7 +763,10 @@ int dtaus_writeC(FILE *f, char **valuesA, char **values, char **text)
   else
     for (i=0; i<recC[C_EUR].len; i++) buf[recC[C_EUR].pos+i] = tmp[i];
 #else
-  for (i=0; i<recC[C_VAL].len; i++) buf[recC[C_VAL].pos+i] = tmp[i];
+  if (use_euro)
+    for (i=0; i<recC[C_VAL].len; i++) buf[recC[C_VAL].pos+i] = tmp[i];
+  else
+    for (i=0; i<recC[C_DM].len; i++) buf[recC[C_DM].pos+i] = tmp[i];
 #endif
   if (values[C_MYKTO])
     sprintf (tmp, "%s", padzeroclip (strip_nondigits (values[C_MYKTO]),10));
@@ -753,7 +836,10 @@ int dtaus_writeE(FILE *f, int count, bigint sum, bigint blz, bigint kto)
   else
     for (i=0; i<recE[E_EUR].len; i++) buf[recE[E_EUR].pos+i] = tmp[i];
 #else
-  for (i=0; i<recE[E_VAL].len; i++) buf[recE[E_VAL].pos+i] = tmp[i];
+  if (use_euro)
+    for (i=0; i<recE[E_VAL].len; i++) buf[recE[E_VAL].pos+i] = tmp[i];
+  else
+    for (i=0; i<recE[E_DM].len; i++) buf[recE[E_DM].pos+i] = tmp[i];
 #endif
   bigint_sprintf (tmp, "%s", kto);
   padzeroclip (tmp,17);
@@ -824,8 +910,8 @@ void printctlndate(FILE *f, char *field, char *value)
 void dtaus2control (char *cdtaus, char *ccontrol)
 {
   FILE *fdtaus, *fcontrol;
-  void *buf;
-  void *bufp;
+  char *buf;
+  char *bufp;
   char tmp[30];
   char x[30];
   int index;
@@ -857,16 +943,12 @@ void dtaus2control (char *cdtaus, char *ccontrol)
   /* 
    * Record A lesen
    */
-  if (dtaus_nextrec(buf, fdtaus) == 1) {
+  if (dtaus_nextrec((void *)buf, fdtaus) == 1) {
     if (dtaus_char(buf,4) == 'A') {
       fprintf(fcontrol, "BEGIN {\n");
       bufp = buf;
 
-#ifndef DEFAULT_EURO
-      for (index=A_TRANS; index <= A_EURO; index++) {
-#else
-      for (index=A_TRANS; index < A_EURO; index++) {
-#endif
+      for (index=A_TRANS; index < A_LOOP; index++) {
 	bufp = buf + recA[index].pos;
 	memcpy(tmp, bufp, recA[index].len); tmp[recA[index].len] = '\0';
 	if (index == A_DATE || index == A_TODO)
@@ -875,10 +957,14 @@ void dtaus2control (char *cdtaus, char *ccontrol)
 	  printctln(fcontrol, recA[index].name, strip_zeros(strip_spaces(tmp)));
       }
 
-#ifndef DEFAULT_EURO
-      if (tmp[recA[index].pos] == '1')
+      bufp = buf + recA[A_CURR].pos;
+      if (*bufp == '1') {
 	use_euro = 1;
-#endif
+	fprintf(fcontrol, "  Euro\n");
+      } else {
+	use_euro = 0;
+	fprintf(fcontrol, "  DM\n");
+      }
 
       fprintf(fcontrol, "}\n\n");
     } else {
@@ -893,28 +979,38 @@ void dtaus2control (char *cdtaus, char *ccontrol)
   /*
    * Record C lesen
    */
-  if (dtaus_nextrec(buf, fdtaus) == 1) {
+  if (dtaus_nextrec((void *)buf, fdtaus) == 1) {
     while (dtaus_char(buf,4) == 'C') {
       bufp = buf + 128;
-      if (dtaus_nextrec(bufp, fdtaus) != 1) {
+      if (dtaus_nextrec((void *)bufp, fdtaus) != 1) {
 	fprintf (stderr, "Der zweite Teil der Transaktion ist kaputt.\n");
 	return;
       } else {
 	fprintf(fcontrol, "{\n");
 
-	for (index=C_NAME; index < C_EURO; index++) {
+	for (index=C_NAME; index < C_LOOP; index++) {
 #ifndef DEFAULT_EURO
 	  if (use_euro && index == C_VAL)
 	    index = C_EUR;
+#else
+	  if (!use_euro && index == C_VAL)
+	    index = C_DM;
 #endif
 	  bufp = buf + recC[index].pos;
 	  memcpy(tmp, bufp, recC[index].len); tmp[recC[index].len] = '\0';
+
+	  /*
+	   * C_EUR and C_DM are outside of the loop, can only be
+	   * selected for the non-default currency, but the value
+	   * should be stored in the normal record field.
+	   */
 #ifndef DEFAULT_EURO
 	  if (index == C_EUR)
-	    printctln(fcontrol, recC[C_VAL].name, strip_zeros(string2real(tmp)));
-	  else
+#else
+	  if (index == C_DM)
 #endif
-	  if (index == C_VAL)
+	    printctln(fcontrol, recC[C_VAL].name, strip_zeros(string2real(tmp)));
+	  else if (index == C_VAL)
 	    printctln(fcontrol, recC[index].name, strip_zeros(string2real(tmp)));
 	  else if (index == C_TRANS)
 	    printctln(fcontrol, recC[index].name, strip_zeros(string2trans(tmp)));
@@ -923,6 +1019,9 @@ void dtaus2control (char *cdtaus, char *ccontrol)
 #ifndef DEFAULT_EURO
 	  if (use_euro && index == C_EUR)
 	    index = C_VAL;
+#else
+	  if (!use_euro && index == C_DM)
+	    index = C_VAL;
 #endif
 	}
 
@@ -944,7 +1043,7 @@ void dtaus2control (char *cdtaus, char *ccontrol)
 	  if (res.rem) extC++;
 	}
       }
-      if (dtaus_nextrec(buf, fdtaus) != 1)
+      if (dtaus_nextrec((void *)buf, fdtaus) != 1)
 	memset (buf, 0, sizeof(buf));
 
       /*
@@ -963,7 +1062,7 @@ void dtaus2control (char *cdtaus, char *ccontrol)
 	    printctln(fcontrol, string2ext(x), strip_spaces(tmp));
 	  }
 	}
-	if (dtaus_nextrec(buf, fdtaus) != 1)
+	if (dtaus_nextrec((void *)buf, fdtaus) != 1)
 	  memset (buf, 0, sizeof(buf));
 	extC--;
       }
@@ -983,20 +1082,28 @@ void dtaus2control (char *cdtaus, char *ccontrol)
 #ifndef DEFAULT_EURO
 	if (use_euro && index == E_VAL)
 	  index = E_EUR;
+#else
+	if (!use_euro && index == E_VAL)
+	  index = E_DM;
 #endif
+
 	bufp = buf + recE[index].pos;
 	memcpy(tmp, bufp, recE[index].len); tmp[recE[index].len] = '\0';
+
 #ifndef DEFAULT_EURO
 	if (index == E_VAL || index == E_EUR)
 #else
-	if (index == E_VAL)
+	if (index == E_VAL || index == E_DM)
 #endif
-	  printctln(fcontrol, recE[index].name, strip_zeros(string2real(tmp)));
+	  printctln(fcontrol, recE[E_VAL].name, strip_zeros(string2real(tmp)));
 	else
 	  printctln(fcontrol, recE[index].name, strip_zeros(tmp));
 #ifndef DEFAULT_EURO
 	  if (use_euro && index == E_EUR)
 	    index = E_VAL;
+#else
+	  if (!use_euro && index == E_DM)
+	    index = E_VAL;
 #endif
       }
 
@@ -1013,13 +1120,12 @@ void dtaus2control (char *cdtaus, char *ccontrol)
   fclose(fdtaus);
 }
 
-int control2dtaus (char *ccontrol, char *cdtaus, char *cbeleg, char *ccheck)
+int control2dtaus (char *ccontrol, char *cdtaus, char *cbeleg, char *ccheck, char *latex)
 {
   FILE *fdtaus, *fcontrol, *fbeleg, *fcheck;
   void *buf;
   char *ident;
   int  recindex;
-  char tmp[30];
   char line[100];
   char *valA[A_LEN], *valC[C_LEN];
   int count;
@@ -1027,6 +1133,11 @@ int control2dtaus (char *ccontrol, char *cdtaus, char *cbeleg, char *ccheck)
   char **text = NULL;
   char *cp;
   int textindex = 0;
+  int len, i;
+  char *type = NULL;
+  char *currency = NULL;
+  char date_todo[11];
+  char ssum_val[30], ssum_kto[30], ssum_blz[30];
 
   if (!cdtaus) {
     if (!(fdtaus = fopen("dtaus0.txt", "w")))
@@ -1077,43 +1188,46 @@ int control2dtaus (char *ccontrol, char *cdtaus, char *cbeleg, char *ccheck)
     while (strlen(line) && line[0] != '}') {
       ident = extract_ident(line);
       if ((recindex = rec_index(ident, REC_A)) != -1)
-#ifndef DEFAULT_EURO
 	{
-#endif
 	if (recA[recindex].type != IGN)
 	  if ((valA[recindex] = (char *)malloc (strlen(line)+1)))
 	    strcpy(valA[recindex], line);
-#ifndef DEFAULT_EURO
 	} else {
 	  if (! strcasecmp (ident, "euro"))
 	    use_euro = 1;
+	  if (! strcasecmp (ident, "dm"))
+	    use_euro = 0;
 	}
-#endif
       control_nextline ((void *)line, 100, fcontrol);
     }
     if (((recindex = rec_index("art", REC_A)) != -1) && valA[recindex] && strlen(valA[recindex])) {
+      if (valA[recindex][0] == 'L')
+	type = strdup ("Sammeleinziehungsauftrag");
+      else if (valA[recindex][0] == 'G')
+	type = strdup ("Sammelueberweisungsauftrag");
+      else
+	type = strdup ("Sammelauftrag");
+
+      if (use_euro)
+	currency = strdup ("Euro");
+      else
+	currency = strdup ("DM");
+
+      if (valA[A_TODO])
+	sprintf (date_todo, valA[A_TODO]);
+      else
+	memset (date_todo, 0, sizeof (date_todo));
+
       fprintf(fbeleg, "\n\n");
       fprintf(fbeleg, "\n    Begleitzettel\n\n");
       fprintf(fbeleg, "\n    Belegloser Datentraegeraustausch\n\n");
-      if (valA[recindex][0] == 'L')
-	fprintf(fbeleg, "\n    Sammeleinziehungsauftrag\n\n");
-      else if (valA[recindex][0] == 'G')
-	fprintf(fbeleg, "\n    Sammelueberweisungsauftrag\n\n");
-      else
-	fprintf(fbeleg, "\n    Sammelauftrag\n\n");
+      fprintf(fbeleg, "\n    %s\n\n", type);
       fprintf(fbeleg, "\n    VOL ........................:\n");
       fprintf(fbeleg, "\n    Erstellungsdatum ...........: %s\n", get_date());
-      if (valA[A_TODO]) {
-	fprintf(fbeleg, "\n    Ausfuehrugsdatum ...........: %s\n", valA[A_TODO]);
+      if (date_todo) {
+	fprintf(fbeleg, "\n    Ausfuehrungsdatum ..........: %s\n", date_todo);
       }
-#ifndef DEFAULT_EURO
-      if (use_euro)
-	fprintf(fbeleg, "\n    Waehrung ...................: Euro\n");
-      else
-	fprintf(fbeleg, "\n    Waehrung ...................: DM\n");
-#else
-      fprintf(fbeleg, "\n    Waehrung ...................: Euro\n");
-#endif
+      fprintf(fbeleg, "\n    Waehrung ...................: %s\n", currency);
     }
     if (!dtaus_writeA(fdtaus, valA)) {
       fprintf (stderr, "Konnte den Anfangsdatensatz nicht schreiben.\n");
@@ -1128,14 +1242,10 @@ int control2dtaus (char *ccontrol, char *cdtaus, char *cbeleg, char *ccheck)
     else
       fprintf (fcheck, "    Sammelauftrag\n\n");
     fprintf (fcheck, "    Erstellungsdatum : %s\n\n", get_date());
-#ifndef DEFAULT_EURO
     if (use_euro)
       fprintf (fcheck, "    Waehrung         : Euro\n\n\n");
     else
       fprintf (fcheck, "    Waehrung         : DM\n\n\n");
-#else
-    fprintf (fcheck, "    Waehrung         : Euro\n\n\n");
-#endif
     fprintf (fcheck, "     %-10s  %-8s  %-30s   %12s\n", "Kontonr.", "BLZ", "Name", "Betrag");
     fprintf (fcheck, "    --------------------------------------------------------------------\n");
   } else {
@@ -1185,10 +1295,31 @@ int control2dtaus (char *ccontrol, char *cdtaus, char *cbeleg, char *ccheck)
 		}
 	      }
 	    } else {
-	      if ((valC[recindex] = (char *)malloc (strlen(line)+1)))
-		strcpy(valC[recindex], line);
-	      else
-		return 0;
+	      len = strlen(line);
+	      if (recindex == C_VAL) {
+		/* Convert commast to dots for later processing */
+		for (i=0; line[i]; i++) if (line[i] == ',') line[i] = '.';
+
+		if ((cp = strchr (line, '.')) == NULL) {
+		  if (!(valC[recindex] = (char *)malloc (strlen(line)+4)))
+		    return 0;
+		  sprintf (valC[recindex], "%s.00", line);
+		} else if ( ((len = cp - line + 3)) < strlen (line)) {
+		  if (!(valC[recindex] = (char *)malloc (len+1)))
+                    return 0;
+                  strncpy (valC[recindex], line, len);
+		  valC[recindex][len] = '\0';
+		} else {
+                  if (!(valC[recindex] = (char *)malloc (strlen(line)+1)))
+                    return 0;
+		  strcpy(valC[recindex], line);
+		}
+	      } else {
+		if ((valC[recindex] = (char *)malloc (strlen(line)+1)))
+		  strcpy(valC[recindex], line);
+		else
+		  return 0;
+	      }
 	    }
 	  }
 	control_nextline ((void *)line, 100, fcontrol);
@@ -1219,23 +1350,30 @@ int control2dtaus (char *ccontrol, char *cdtaus, char *cbeleg, char *ccheck)
    */
   dtaus_writeE(fdtaus, count, sum_val, sum_blz, sum_kto);
   fprintf (fcheck, "    --------------------------------------------------------------------\n");
-  bigint_sprintf (tmp, "%s", sum_val);
   fprintf (fbeleg, "\n    Anzahl .....................: %d\n", count);
-  recindex=strlen(tmp);
-  tmp[recindex+1] = '\0';
-  tmp[recindex] = tmp[recindex-1];
-  tmp[recindex-1] = tmp[recindex-2];
-  tmp[recindex-2] = '.';
-  fprintf (fcheck, "     %-52s %14s\n", "Summe", tmp);
-  fprintf (fbeleg, "\n    Summe ......................: %s\n", tmp);
-  bigint_sprintf (tmp, "%s", sum_kto);
-  fprintf (fbeleg, "\n    Kontrollsumme Kontonummern .: %s\n", tmp);
-  bigint_sprintf (tmp, "%s", sum_blz);
-  fprintf (fbeleg, "\n    Kontrollsumme Bankleitzahlen: %s\n", tmp);
+  bigint_sprintf (ssum_val, "%s", sum_val);
+  recindex=strlen(ssum_val);
+  ssum_val[recindex+1] = '\0';
+  ssum_val[recindex] = ssum_val[recindex-1];
+  ssum_val[recindex-1] = ssum_val[recindex-2];
+  ssum_val[recindex-2] = '.';
+  fprintf (fcheck, "     %-52s %14s\n", "Summe", ssum_val);
+  fprintf (fbeleg, "\n    Summe ......................: %s\n", ssum_val);
+  bigint_sprintf (ssum_kto, "%s", sum_kto);
+  fprintf (fbeleg, "\n    Kontrollsumme Kontonummern .: %s\n", ssum_kto);
+  bigint_sprintf (ssum_blz, "%s", sum_blz);
+  fprintf (fbeleg, "\n    Kontrollsumme Bankleitzahlen: %s\n", ssum_blz);
   fprintf (fbeleg, "\n    Unsere Kontonummer .........: %s\n", valA[A_KTO]);
   fprintf (fbeleg, "\n    Unsere Bankleitzahl ........: %s\n", valA[A_BLZ]);
   fprintf (fbeleg, "\n\n\n\n\n    __________________________________________________\n");
   fprintf (fbeleg, "    Ort, Datum                     Unterschrift\n");
+
+  if (latex)
+    generate_latex_receipt (latex, type, get_date(), date_todo,
+			    currency, count,
+			    ssum_val, ssum_kto, ssum_blz,
+			    valA[A_KTO], valA[A_BLZ]);
+
   for (recindex=0; recindex<A_LEN; recindex++)
     if (valA[recindex])
       free(valA[recindex]);
