@@ -16,7 +16,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111, USA.
 
-    $Id: dtaus.h,v 1.2 1998/07/04 20:35:43 joey Exp $
+    $Id: dtaus.h,v 1.3 2004/08/06 20:23:12 joey Exp $
  */
 
 #ifndef _DTAUS_H_
@@ -24,6 +24,6 @@
 
 void dtaus2control (char *cdtaus, char *ccontrol);
 
-int control2dtaus (char *ccontrol, char *cdtaus, char *cbeleg, char *ccheck);
+int control2dtaus (char *ccontrol, char *cdtaus, char *cbeleg, char *ccheck, char *latex);
 
 #endif /* _DTAUS_H_ */
