@@ -1,6 +1,6 @@
 /*
     main.c - Belegloser Datentrgeraustausch mit einer Bank
-    Copyright (c) 1996,8,2001  Martin Schulze <joey@infodrom.org>
+    Copyright (c) 1996,8,2001-4  Martin Schulze <joey@infodrom.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,10 +16,10 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111, USA.
 
-    $Id: main.c,v 1.9 2001/11/18 20:19:31 joey Exp $
+    $Id: main.c,v 1.20 2004/08/06 21:14:06 joey Exp $
  */
 
-static char version[] = "0.5";
+static char version[] = "0.7";
 
 #include <stdio.h>
 #include <sys/stat.h>
@@ -28,16 +28,29 @@ static char version[] = "0.5";
 #include <stdlib.h>
 #include "dtaus.h"
 
+#define FN_DTAUS   "dtaus0.txt"
+#define FN_CONTROL "dtaus0.ctl"
+#define FN_BELEG   "dtaus0.doc"
+#define FN_CHECK   "dtaus0.sik"
+#define FN_LATEX   "dtaus0.tex"
+
+char *dtaus   = FN_DTAUS;
+char *control = FN_CONTROL;
+char *beleg   = FN_BELEG;
+char *check   = FN_CHECK;
+char *latex   = NULL;
+
 void help ()
 {
   printf ("dtaus - Belegloser Datentrgeraustausch mit einer Bank\n\n");
-  printf ("  -dtaus        Erzeugt eine Bankdatei\n");
-  printf ("  -control      Liest eine Bankdatei und erzeugt die Kontrolldatei\n");
+  printf ("  -dtaus         Erzeugt eine Bankdatei\n");
+  printf ("  -control       Liest eine Bankdatei und erzeugt die Kontrolldatei\n");
   printf ("\n");
-  printf ("  -d <dtaus>    Bankdatei [dtaus0.txt]\n");
-  printf ("  -c <control>  Steuerdatei [dtaus0.ctl]\n");
-  printf ("  -b <begleit>  Begleitzettel fr die Bank dtaus0.doc]\n");
-  printf ("  -o <kontroll> Kontrolldatei zum Abheften [dtaus0.sik]\n");
+  printf ("  -d <dtaus>     Bankdatei [%s]\n", FN_DTAUS);
+  printf ("  -c <control>   Steuerdatei [%s]\n", FN_CONTROL);
+  printf ("  -b <begleit>   Begleitzettel fr die Bank [%s]\n", FN_BELEG);
+  printf ("  -l [<begleit>] Begleitzettel als LaTeX [%s]\n", FN_LATEX);
+  printf ("  -o <kontroll>  Kontrolldatei zum Abheften [%s]\n", FN_CHECK);
 }
 
 #define DTAUS   1
@@ -45,45 +58,42 @@ void help ()
 
 int main (int argc, char **argv)
 {
-  char *dtaus[60];
-  char *control[60];
-  char *beleg[60];
-  char *check[60];
   int action = 0;
   int i = 0;
   struct stat sbuf;
 
-  strcpy ((char *)dtaus, "dtaus0.txt");
-  strcpy ((char *)control, "dtaus0.ctl");
-  strcpy ((char *)beleg, "dtaus0.doc");
-  strcpy ((char *)check, "dtaus0.sik");
-
   while (argc - i > 1) {
     i++;
     if ( !strcmp(argv[i], "-h") ) {
       help(); exit(0);
     } else if ( !strcmp(argv[i], "-v") ) {
-      printf ("dtaus version %s - Copyright (c) 1997,8,2001 by Martin Schulze <joey@infodrom.org>\n", version);
+      printf ("dtaus version %s - Copyright (c) 1997,8,2001,4 by Martin Schulze <joey@infodrom.org>\n", version);
       exit (0);
     } else if ( !strcmp(argv[i], "-d") ) {
       if (argc - i > 1) {
 	i++;
-	strcpy ((char *)dtaus, argv[i]);
+	dtaus = argv[i];
       }
     } else if ( !strcmp(argv[i], "-c") ) {
       if (argc - i > 1) {
 	i++;
-	strcpy ((char *)control, argv[i]);
+	control = argv[i];
       }
     } else if ( !strcmp(argv[i], "-b") ) {
       if (argc - i > 1) {
 	i++;
-	strcpy ((char *)beleg, argv[i]);
+	beleg = argv[i];
       }
+    } else if ( !strcmp(argv[i], "-l") ) {
+      if (argc - i > 1 && argv[i+1][0] != '-') {
+	i++;
+	latex = argv[i];
+      } else
+	latex = FN_LATEX;
     } else if ( !strcmp(argv[i], "-o") ) {
       if (argc - i > 1) {
 	i++;
-	strcpy ((char *)check, argv[i]);
+	check = argv[i];
       }
     } else if ( !strcmp(argv[i], "-dtaus") ) {
       action = DTAUS;
@@ -93,17 +103,23 @@ int main (int argc, char **argv)
   }
 
   if (action == DTAUS) {
-    if (!stat((char *)control, &sbuf)) {
-      if (control2dtaus ((char *)control, (char *)dtaus, (char *)beleg, (char *)check) == 0)
+    if (!strcmp("-", control) || !stat(control, &sbuf)) {
+      if (control2dtaus (control, dtaus, beleg, check, latex) == 0)
 	exit (1);
     }
-    else exit (1);
+    else {
+      fprintf( stderr, "Can't stat %s\n", control);
+      exit (1);
+    }
   } else if (action == CONTROL) {
-    if (!stat((char *)dtaus, &sbuf))
-      dtaus2control ((char *)dtaus, (char *)control);
-    else exit (1);
+    if (!strcmp("-", dtaus) || !stat(dtaus, &sbuf))
+      dtaus2control (dtaus, control);
+    else {
+      fprintf( stderr, "Can't stat %s\n", dtaus);
+      exit (1);
+    }
   } else {
-    printf ("Keine Routine angegeben (-dtaus bzw. -control vergessen).\n");
+    fprintf (stderr, "Keine Routine angegeben (-dtaus bzw. -control vergessen).\n");
     exit (1);
   }
   exit (0);
